#pragma once
#include "core/tool_data.hpp"

namespace horizon {
class ToolDataFromPlacePowerSymbol : public ToolData {};
} // namespace horizon
